=========
pytest-qt
=========

:Repository: `GitHub <https://github.com/pytest-dev/pytest-qt>`_
:Version: |version|
:License: `MIT <https://opensource.org/licenses/MIT>`_
:Author: Bruno Oliveira

.. toctree::
    :maxdepth: 2

    intro
    tutorial
    logging
    signals
    wait_until
    wait_callback
    virtual_methods
    modeltester
    qapplication
    note_dialogs
    troubleshooting
    reference
    changelog
